@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
@@ -26,9 +26,11 @@
 
 #include <QtGui/qdialog.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Gui)
 
-#ifndef QT_NO_PRINTDIALOG
+#ifndef QT_NO_PRINTER
 
 class QAbstractPrintDialogPrivate;
 class QPrinter;
@@ -37,6 +39,7 @@ class QPrinter;
 class Q_GUI_EXPORT QAbstractPrintDialog : public QDialog
 {
     Q_DECLARE_PRIVATE(QAbstractPrintDialog)
+    Q_OBJECT
 
 public:
     enum PrintRange {
@@ -55,6 +58,8 @@ public:
 
     Q_DECLARE_FLAGS(PrintDialogOptions, PrintDialogOption)
 
+#ifndef QT_NO_PRINTDIALOG
+
     explicit QAbstractPrintDialog(QPrinter *printer, QWidget *parent = 0);
 
     virtual int exec() = 0;
@@ -82,10 +87,14 @@ protected:
 
 private:
     Q_DISABLE_COPY(QAbstractPrintDialog)
+
+#endif // QT_NO_PRINTDIALOG
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(QAbstractPrintDialog::PrintDialogOptions)
 
-#endif // QT_NO_PRINTDIALOG
+#endif // QT_NO_PRINTER
+
+QT_END_HEADER
 
 #endif // QABSTRACTPRINTDIALOG_H
