@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
@@ -26,13 +26,17 @@
 
 #include <stddef.h>
 
-#define QT_VERSION_STR   "4.1.0"
+#define QT_VERSION_STR   "4.3.0"
 /*
    QT_VERSION is (major << 16) + (minor << 8) + patch.
 */
-#define QT_VERSION 0x040100
+#define QT_VERSION 0x040300
+/*
+   can be used like #if (QT_VERSION >= QT_VERSION_CHECK(4, 3, 0))
+*/
+#define QT_VERSION_CHECK(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
 
-#define QT_PACKAGEDATE_STR "2005-12-16"
+#define QT_PACKAGEDATE_STR "2007-05-25"
 
 #if !defined(QT_BUILD_MOC)
 #include <QtCore/qconfig.h>
@@ -73,6 +77,12 @@
 
 #if defined(__APPLE__) && (defined(__GNUC__) || defined(__xlC__) || defined(__xlc__))
 #  define Q_OS_DARWIN
+#  define Q_OS_BSD4
+#  ifdef __LP64__
+#    define Q_OS_DARWIN64
+#  else
+#    define Q_OS_DARWIN32
+#  endif
 #elif defined(__CYGWIN__)
 #  define Q_OS_CYGWIN
 #elif defined(MSDOS) || defined(_MSDOS)
@@ -120,7 +130,7 @@
 #  define Q_OS_AIX
 #elif defined(__Lynx__)
 #  define Q_OS_LYNX
-#elif defined(__GNU_HURD__)
+#elif defined(__GNU__)
 #  define Q_OS_HURD
 #elif defined(__DGUX__)
 #  define Q_OS_DGUX
@@ -136,6 +146,8 @@
 #  define Q_OS_UNIXWARE
 #elif defined(__svr4__) && defined(i386) /* Open UNIX 8 + GCC */
 #  define Q_OS_UNIXWARE
+#elif defined(__INTEGRITY)
+#  define Q_OS_INTEGRITY
 #elif defined(__MAKEDEPEND__)
 #else
 #  error "Qt has not been ported to this OS - talk to qt-bugs@trolltech.com"
@@ -146,8 +158,13 @@
 #endif
 
 #if defined(Q_OS_DARWIN)
-#  define Q_OS_MAC /* Q_OS_MAC is mostly for compatiblity, but also more clear */
-#  define Q_OS_MACX /* Q_OS_MACX is only for compatiblity.*/
+#  define Q_OS_MAC /* Q_OS_MAC is mostly for compatibility, but also more clear */
+#  define Q_OS_MACX /* Q_OS_MACX is only for compatibility.*/
+#  if defined(Q_OS_DARWIN64)
+#     define Q_OS_MAC64
+#  elif defined(Q_OS_DARWIN32)
+#     define Q_OS_MAC32
+#  endif
 #endif
 
 #if defined(Q_OS_MSDOS) || defined(Q_OS_OS2) || defined(Q_OS_WIN)
@@ -188,6 +205,10 @@
    Should be sorted most to least authoritative.
 */
 
+#if defined(__ghs)
+#  define Q_OUTOFLINE_TEMPLATE inline
+#endif
+
 /* Symantec C++ is now Digital Mars */
 #if defined(__DMC__) || defined(__SC__)
 #  define Q_CC_SYM
@@ -219,6 +240,9 @@
 #    define Q_NO_USING_KEYWORD
 #    define QT_NO_MEMBER_TEMPLATES
 #  endif
+#  if _MSC_VER < 1310
+#     define QT_NO_QOBJECT_CHECK
+#  endif
 /* Intel C++ disguising as Visual C++: the `using' keyword avoids warnings */
 #  if defined(__INTEL_COMPILER)
 #    define Q_CC_INTEL
@@ -226,6 +250,9 @@
 /* x64 does not support mmx intrinsics on windows */
 #  if (defined(Q_OS_WIN64) && defined(_M_X64))
 #    undef QT_HAVE_SSE
+#    undef QT_HAVE_SSE2
+#    undef QT_HAVE_MMX
+#    undef QT_HAVE_3DNOW
 #  endif
 
 
@@ -256,7 +283,6 @@
 /* can we just compare the structures? */
 #    define Q_FULL_TEMPLATE_INSTANTIATION_MEMCMP
 /* these are not useful to our customers */
-#    define QT_QWS_NO_SHM
 #    define QT_NO_QWS_MULTIPROCESS
 #    define QT_NO_QWS_CURSOR
 #  endif
@@ -264,34 +290,36 @@
 #elif defined(__GNUC__)
 #  define Q_CC_GNU
 #  define Q_C_CALLBACKS
+#  if defined(__MINGW32__)
+#    define Q_CC_MINGW
+#  endif
 #  if defined(__INTEL_COMPILER)
 /* Intel C++ also masquerades as GCC 3.2.0 */
 #    define Q_CC_INTEL
-#  else
-#    ifdef __APPLE__
-#      define Q_NO_DEPRECATED_CONSTRUCTORS
-#    endif
-#    if __GNUC__ == 2 && __GNUC_MINOR__ <= 7
-#      define Q_FULL_TEMPLATE_INSTANTIATION
-#    endif
+#  endif
+#  ifdef __APPLE__
+#    define Q_NO_DEPRECATED_CONSTRUCTORS
+#  endif
+#  if __GNUC__ == 2 && __GNUC_MINOR__ <= 7
+#    define Q_FULL_TEMPLATE_INSTANTIATION
+#  endif
 /* GCC 2.95 knows "using" but does not support it correctly */
-#    if __GNUC__ == 2 && __GNUC_MINOR__ <= 95
-#      define Q_NO_USING_KEYWORD
-#      define QT_NO_STL_WCHAR
-#    endif
+#  if __GNUC__ == 2 && __GNUC_MINOR__ <= 95
+#    define Q_NO_USING_KEYWORD
+#    define QT_NO_STL_WCHAR
+#  endif
 /* GCC 3.1 and GCC 3.2 wrongly define _SB_CTYPE_MACROS on HP-UX */
-#    if defined(Q_OS_HPUX) && __GNUC__ == 3 && __GNUC_MINOR__ >= 1
-#      define Q_WRONG_SB_CTYPE_MACROS
-#    endif
+#  if defined(Q_OS_HPUX) && __GNUC__ == 3 && __GNUC_MINOR__ >= 1
+#    define Q_WRONG_SB_CTYPE_MACROS
+#  endif
 /* Apple's GCC 3.1 chokes on our streaming qDebug() */
-#    if defined(Q_OS_DARWIN) && __GNUC__ == 3 && (__GNUC_MINOR__ >= 1 && __GNUC_MINOR__ < 3)
-#      define Q_BROKEN_DEBUG_STREAM
-#    endif
-#    if (defined(__arm__) || defined(__ARMEL__)) && !defined(QT_MOC_CPP)
-#      define Q_PACKED __attribute__ ((__packed__))
-#      define Q_NO_PACKED_REFERENCE
-#    endif
-#  endif /* __INTEL_COMPILER */
+#  if defined(Q_OS_DARWIN) && __GNUC__ == 3 && (__GNUC_MINOR__ >= 1 && __GNUC_MINOR__ < 3)
+#    define Q_BROKEN_DEBUG_STREAM
+#  endif
+#  if (defined(__arm__) || defined(__ARMEL__)) && !defined(QT_MOC_CPP)
+#    define Q_PACKED __attribute__ ((__packed__))
+#    define Q_NO_PACKED_REFERENCE
+#  endif
 
 /* IBM compiler versions are a bit messy. There are actually two products:
    the C product, and the C++ product. The C++ compiler is always packaged
@@ -358,9 +386,18 @@
 /* avoid undefined symbol problems with out-of-line template members */
 #  define Q_OUTOFLINE_TEMPLATE inline
 
+/* The Portland Group C++ compiler is based on EDG and does define __EDG__
+   but the C compiler does not */
+#elif defined(__PGI)
+#  define Q_CC_PGI
+#  if defined(__EDG__)
+#    define Q_CC_EDG
+#  endif
+
 /* Compilers with EDG front end are similar. To detect them we test:
    __EDG documented by SGI, observed on MIPSpro 7.3.1.1 and KAI C++ 4.0b
-   __EDG__ documented in EDG online docs, observed on Compaq C++ V6.3-002 */
+   __EDG__ documented in EDG online docs, observed on Compaq C++ V6.3-002
+   and PGI C++ 5.2-4 */
 #elif defined(__EDG) || defined(__EDG__)
 #  define Q_CC_EDG
 /* From the EDG documentation (does not seem to apply to Compaq C++):
@@ -391,11 +428,7 @@
 #  elif defined(__INTEL_COMPILER)
 #    define Q_CC_INTEL
 
-/* The Portland Group compiler is based on EDG and does define __EDG__ */
-#  elif defined(__PGI)
-#    define Q_CC_PGI
-
-/* Never tested! */
+/* Uses CFront, make sure to read the manual how to tweak templates. */
 #  elif defined(__ghs)
 #    define Q_CC_GHS
 
@@ -500,13 +533,21 @@
     } AFUNC ## __dest_instance__;
 #endif
 
+#ifndef Q_REQUIRED_RESULT
+#  if defined(Q_CC_GNU) && !defined(Q_CC_INTEL) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 1))
+#    define Q_REQUIRED_RESULT __attribute__ ((warn_unused_result))
+#  else
+#    define Q_REQUIRED_RESULT
+#  endif
+#endif
+
 
 /*
    The window system, must be one of: (Q_WS_x)
 
      MACX     - Mac OS X
      MAC9     - Mac OS 9
-     QWS      - Qt/Embedded
+     QWS      - Qtopia Core
      WIN32    - Windows
      X11      - X Window System
      PM       - unsupported
@@ -527,9 +568,14 @@
 #  define Q_WS_PM
 #  error "Qt does not work with OS/2 Presentation Manager or Workplace Shell"
 #elif defined(Q_OS_UNIX)
-#  if defined(Q_OS_DARWIN) && !defined(__USE_WS_X11__)
+#  if defined(Q_OS_MAC) && !defined(__USE_WS_X11__) && !defined(Q_WS_QWS)
 #    define Q_WS_MAC
 #    define Q_WS_MACX
+#    if defined(Q_OS_MAC64)
+#      define Q_WS_MAC64
+#    elif defined(Q_OS_MAC32)
+#      define Q_WS_MAC32
+#    endif
 #  elif !defined(Q_WS_QWS)
 #    define Q_WS_X11
 #  endif
@@ -539,9 +585,10 @@
 #  define Q_WS_WIN
 #endif
 
-
 /*
    Size-dependent types (architechture-dependent byte order)
+
+   Make sure to update QMetaType when changing these typedefs
 */
 
 typedef signed char qint8;         /* 8 bit signed */
@@ -565,21 +612,41 @@ typedef unsigned long long quint64; /* 64 bit unsigned */
 typedef qint64 qlonglong;
 typedef quint64 qulonglong;
 
-#if defined(Q_OS_WIN64)
-# define QT_POINTER_SIZE 8
-#elif defined(Q_OS_WIN32)
-# define QT_POINTER_SIZE 4
+#ifndef QT_POINTER_SIZE
+#  if defined(Q_OS_WIN64)
+#   define QT_POINTER_SIZE 8
+#  elif defined(Q_OS_WIN32)
+#   define QT_POINTER_SIZE 4
+#  endif
 #endif
 
 #define Q_INIT_RESOURCE(name) \
-    do { extern int qInitResources_ ## name (); \
-    qInitResources_ ## name (); } while (0)
+    do { extern int qInitResources_ ## name ();       \
+        qInitResources_ ## name (); } while (0)
 #define Q_CLEANUP_RESOURCE(name) \
-    do { extern int qCleanupResources_ ## name (); \
+    do { extern int qCleanupResources_ ## name ();    \
         qCleanupResources_ ## name (); } while (0)
 
 #if defined(__cplusplus)
 
+/*
+  quintptr and qptrdiff is guaranteed to be the same size as a pointer, i.e.
+
+      sizeof(void *) == sizeof(quintptr)
+      && sizeof(void *) == sizeof(qptrdiff)
+*/
+template <int> class QUintForSize    { private: typedef void    Type; };
+template <>    class QUintForSize<4> { public:  typedef quint32 Type; };
+template <>    class QUintForSize<8> { public:  typedef quint64 Type; };
+template <typename T> class QUintForType : public QUintForSize<sizeof(T)> { };
+typedef QUintForType<void *>::Type quintptr;
+
+template <int> class QIntForSize    { private: typedef void   Type; };
+template <>    class QIntForSize<4> { public:  typedef qint32 Type; };
+template <>    class QIntForSize<8> { public:  typedef qint64 Type; };
+template <typename T> class QIntForType : public QIntForSize<sizeof(T)> { };
+typedef QIntForType<void *>::Type qptrdiff;
+
 /*
    Useful type definitions for Qt
 */
@@ -597,20 +664,31 @@ typedef unsigned long ulong;
    Constant bool values
 */
 
-#ifndef TRUE
-#define TRUE true
-#define FALSE false
+#ifndef QT_LSB /* the LSB defines TRUE and FALSE for us */
+#  ifndef TRUE
+#   define TRUE true
+#   define FALSE false
+#  endif
 #endif
 
+#if defined(Q_OS_MAC) && !defined(Q_CC_INTEL)
+#define QT_BEGIN_HEADER extern "C++" {
+#define QT_END_HEADER }
+#else
+#define QT_BEGIN_HEADER
+#define QT_END_HEADER
+#endif
+
+QT_BEGIN_HEADER
 /*
    Proper for-scoping in VC++6 and MIPSpro CC
 */
-
-#if (defined(Q_CC_MSVC) && !defined(Q_CC_MSVC_NET) && !defined(Q_CC_INTEL)) || defined(Q_CC_MIPS)
-#  define for if(0){}else for
+#ifndef QT_NO_KEYWORDS
+#  if (defined(Q_CC_MSVC) && !defined(Q_CC_MSVC_NET) && !defined(Q_CC_INTEL)) || defined(Q_CC_MIPS) || (defined(Q_CC_HPACC) && defined(__ia64))
+#    define for if(0){}else for
+#  endif
 #endif
 
-
 /*
    Workaround for static const members on MSVC++.
 */
@@ -642,7 +720,7 @@ typedef unsigned long ulong;
 #ifndef Q_DECL_VARIABLE_DEPRECATED
 #  define Q_DECL_VARIABLE_DEPRECATED Q_DECL_DEPRECATED
 #endif
-#ifndef QT3_SUPPORT_CONSTRUCTOR
+#ifndef Q_DECL_CONSTRUCTOR_DEPRECATED
 #  if defined(Q_MOC_RUN)
 #    define Q_DECL_CONSTRUCTOR_DEPRECATED Q_DECL_CONSTRUCTOR_DEPRECATED
 #  elif defined(Q_NO_DEPRECATED_CONSTRUCTORS)
@@ -651,6 +729,33 @@ typedef unsigned long ulong;
 #    define Q_DECL_CONSTRUCTOR_DEPRECATED Q_DECL_DEPRECATED
 #  endif
 #endif
+
+#if defined(QT_NO_DEPRECATED)
+/* disable Qt3 support as well */
+#  undef QT3_SUPPORT_WARNINGS
+#  undef QT3_SUPPORT
+#  undef QT_DEPRECATED
+#  undef QT_DEPRECATED_VARIABLE
+#  undef QT_DEPRECATED_CONSTRUCTOR
+#elif defined(QT_DEPRECATED_WARNINGS)
+/* enable Qt3 support warnings as well */
+#  undef QT3_SUPPORT_WARNINGS
+#  define QT3_SUPPORT_WARNINGS
+#  undef QT_DEPRECATED
+#  define QT_DEPRECATED Q_DECL_DEPRECATED
+#  undef QT_DEPRECATED_VARIABLE
+#  define QT_DEPRECATED_VARIABLE Q_DECL_VARIABLE_DEPRECATED
+#  undef QT_DEPRECATED_CONSTRUCTOR
+#  define QT_DEPRECATED_CONSTRUCTOR explicit Q_DECL_CONSTRUCTOR_DEPRECATED
+#else
+#  undef QT_DEPRECATED
+#  define QT_DEPRECATED
+#  undef QT_DEPRECATED_VARIABLE
+#  define QT_DEPRECATED_VARIABLE
+#  undef QT_DEPRECATED_CONSTRUCTOR
+#  define QT_DEPRECATED_CONSTRUCTOR
+#endif
+
 #if defined(QT3_SUPPORT_WARNINGS)
 #  if !defined(QT_COMPAT_WARNINGS) /* also enable compat */
 #    define QT_COMPAT_WARNINGS
@@ -672,21 +777,7 @@ typedef unsigned long ulong;
 #  undef QT3_SUPPORT_CONSTRUCTOR
 #  define QT3_SUPPORT_CONSTRUCTOR explicit
 #endif
-#if defined(QT_COMPAT_WARNINGS)
-#  undef QT_COMPAT
-#  define QT_COMPAT Q_DECL_DEPRECATED
-#  undef QT_COMPAT_VARIABLE
-#  define QT_COMPAT_VARIABLE Q_DECL_VARIABLE_DEPRECATED
-#  undef QT_COMPAT_CONSTRUCTOR
-#  define QT_COMPAT_CONSTRUCTOR explicit Q_DECL_CONSTRUCTOR_DEPRECATED
-#elif defined(QT_COMPAT) /* define back to nothing */
-#  undef QT_COMPAT
-#  define QT_COMPAT
-#  undef QT_COMPAT_VARIABLE
-#  define QT_COMPAT_VARIABLE
-#  undef QT_COMPAT_CONSTRUCTOR
-#  define QT_COMPAT_CONSTRUCTOR
-#endif
+
 /* moc compats (signals/slots) */
 #ifndef QT_MOC_COMPAT
 #  if defined(QT3_SUPPORT)
@@ -699,9 +790,26 @@ typedef unsigned long ulong;
 #  define QT_MOC_COMPAT
 #endif
 
+#ifdef QT_ASCII_CAST_WARNINGS
+#  define QT_ASCII_CAST_WARN Q_DECL_DEPRECATED
+#  if defined(Q_CC_GNU) && __GNUC__ < 4
+     /* gcc < 4 doesn't like Q_DECL_DEPRECATED in front of constructors */
+#    define QT_ASCII_CAST_WARN_CONSTRUCTOR
+#  else
+#    define QT_ASCII_CAST_WARN_CONSTRUCTOR Q_DECL_CONSTRUCTOR_DEPRECATED
+#  endif
+#else
+#  define QT_ASCII_CAST_WARN
+#  define QT_ASCII_CAST_WARN_CONSTRUCTOR
+#endif
+
 #ifdef __i386__
 #  if defined(Q_CC_GNU)
+#if !defined(Q_CC_INTEL) && ((100*(__GNUC__ - 0) + 10*(__GNUC_MINOR__ - 0) + __GNUC_PATCHLEVEL__) >= 332)
 #    define QT_FASTCALL __attribute__((regparm(3)))
+#else
+#    define QT_FASTCALL
+#endif
 #  elif defined(Q_CC_MSVC)
 #    define QT_FASTCALL __fastcall
 #  else
@@ -713,9 +821,13 @@ typedef unsigned long ulong;
 
 typedef int QNoImplicitBoolCast;
 
+#if defined(QT_ARCH_ARM) || (defined(QT_ARCH_MIPS) && !defined(Q_OS_IRIX))
+#define QT_NO_FPU
+#endif
+
 #if defined(QT_COORD_TYPE)
 typedef QT_COORD_TYPE qreal;
-#elif defined(__arm__)
+#elif defined(QT_NO_FPU)
 typedef float qreal;
 #else
 typedef double qreal;
@@ -777,7 +889,7 @@ class QDataStream;
 #  ifdef MAC_OS_X_VERSION_MIN_REQUIRED
 #    undef MAC_OS_X_VERSION_MIN_REQUIRED
 #  endif
-#  define MAC_OS_X_VERSION_MIN_REQUIRED MAC_OS_X_VERSION_10_2
+#  define MAC_OS_X_VERSION_MIN_REQUIRED MAC_OS_X_VERSION_10_3
 #  include <AvailabilityMacros.h>
 #  if !defined(MAC_OS_X_VERSION_10_3)
 #     define MAC_OS_X_VERSION_10_3 MAC_OS_X_VERSION_10_2 + 1
@@ -785,7 +897,10 @@ class QDataStream;
 #  if !defined(MAC_OS_X_VERSION_10_4)
 #       define MAC_OS_X_VERSION_10_4 MAC_OS_X_VERSION_10_3 + 1
 #  endif
-#  if (MAC_OS_X_VERSION_MAX_ALLOWED > MAC_OS_X_VERSION_10_4)
+#  if !defined(MAC_OS_X_VERSION_10_5)
+#       define MAC_OS_X_VERSION_10_5 MAC_OS_X_VERSION_10_4 + 1
+#  endif
+#  if (MAC_OS_X_VERSION_MAX_ALLOWED > MAC_OS_X_VERSION_10_5)
 #    error "This version of Mac OS X is unsupported"
 #  endif
 #endif
@@ -817,7 +932,7 @@ class QDataStream;
 #  endif
 #endif
 #ifndef Q_DECL_IMPORT
-#  ifdef Q_OS_WIN
+#  if defined(Q_OS_WIN)
 #    define Q_DECL_IMPORT __declspec(dllimport)
 #  else
 #    define Q_DECL_IMPORT
@@ -826,7 +941,6 @@ class QDataStream;
 
 /*
    Create Qt DLL if QT_DLL is defined (Windows only)
-   or QT_SHARED is defined (Kylix only)
 */
 
 #if defined(Q_OS_WIN)
@@ -872,6 +986,11 @@ class QDataStream;
 #    else
 #      define Q_XML_EXPORT Q_DECL_IMPORT
 #    endif
+#    if defined(QT_BUILD_SCRIPT_LIB)
+#      define Q_SCRIPT_EXPORT Q_DECL_EXPORT
+#    else
+#      define Q_SCRIPT_EXPORT Q_DECL_IMPORT
+#    endif
 #    if defined(QT_BUILD_CANVAS_LIB)
 #      define Q_CANVAS_EXPORT Q_DECL_EXPORT
 #    else
@@ -892,6 +1011,7 @@ class QDataStream;
 #    define Q_CANVAS_EXPORT Q_DECL_IMPORT
 #    define Q_OPENGL_EXPORT Q_DECL_IMPORT
 #    define Q_XML_EXPORT Q_DECL_IMPORT
+#    define Q_SCRIPT_EXPORT Q_DECL_IMPORT
 #    define Q_COMPAT_EXPORT Q_DECL_IMPORT
 #    define Q_TEMPLATEDLL
 #  endif
@@ -914,6 +1034,7 @@ class QDataStream;
 #    define Q_SVG_EXPORT Q_DECL_EXPORT
 #    define Q_OPENGL_EXPORT Q_DECL_EXPORT
 #    define Q_XML_EXPORT Q_DECL_EXPORT
+#    define Q_SCRIPT_EXPORT Q_DECL_EXPORT
 #    define Q_COMPAT_EXPORT Q_DECL_EXPORT
 #  else
 #    define Q_CORE_EXPORT
@@ -923,21 +1044,42 @@ class QDataStream;
 #    define Q_SVG_EXPORT
 #    define Q_OPENGL_EXPORT
 #    define Q_XML_EXPORT
+#    define Q_SCRIPT_EXPORT
 #    define Q_COMPAT_EXPORT
 #  endif
 #endif
 
+// Functions marked as Q_GUI_EXPORT_INLINE were exported and inlined by mistake.
+// Compilers like MinGW complain that the import attribute is ignored.
+#if defined(Q_CC_MINGW)
+#    if defined(QT_BUILD_CORE_LIB)
+#      define Q_CORE_EXPORT_INLINE Q_CORE_EXPORT inline
+#    else
+#      define Q_CORE_EXPORT_INLINE inline
+#    endif
+#    if defined(QT_BUILD_GUI_LIB)
+#      define Q_GUI_EXPORT_INLINE Q_GUI_EXPORT inline
+#    else
+#      define Q_GUI_EXPORT_INLINE inline
+#    endif
+#else
+#    define Q_CORE_EXPORT_INLINE Q_CORE_EXPORT inline
+#    define Q_GUI_EXPORT_INLINE Q_GUI_EXPORT inline
+#endif
+
 /*
    No, this is not an evil backdoor. QT_BUILD_INTERNAL just exports more symbols
    for Trolltech's internal unit tests. If you want slower loading times and more
    symbols that can vanish from version to version, feel free to define QT_BUILD_INTERNAL.
 */
 #if defined(QT_BUILD_INTERNAL) && defined(Q_OS_WIN) && defined(QT_MAKEDLL)
-#    define Q_INTERNAL_EXPORT Q_DECL_EXPORT
+#    define Q_AUTOTEST_EXPORT Q_DECL_EXPORT
+#elif defined(QT_BUILD_INTERNAL) && defined(Q_OS_WIN) && defined(QT_DLL)
+#    define Q_AUTOTEST_EXPORT Q_DECL_IMPORT
 #elif defined(QT_BUILD_INTERNAL) && !defined(Q_OS_WIN) && defined(QT_SHARED)
-#    define Q_INTERNAL_EXPORT Q_DECL_EXPORT
+#    define Q_AUTOTEST_EXPORT Q_DECL_EXPORT
 #else
-#    define Q_INTERNAL_EXPORT
+#    define Q_AUTOTEST_EXPORT
 #endif
 
 /*
@@ -947,15 +1089,22 @@ class QDataStream;
 class QString;
 class Q_CORE_EXPORT QSysInfo {
 public:
-    enum {
+    enum Sizes {
         WordSize = (sizeof(void *)<<3)
     };
 
+#if defined(QT_BUILD_QMAKE)
+    enum Endian {
+        BigEndian,
+        LittleEndian
+    };
+    /* needed to bootstrap qmake */
+    static const int ByteOrder;
+#elif defined(Q_BYTE_ORDER)
     enum Endian {
         BigEndian,
         LittleEndian
 
-#ifdef Q_BYTE_ORDER
 #  ifdef qdoc
         , ByteOrder = <platform-dependent>
 #  elif Q_BYTE_ORDER == Q_BIG_ENDIAN
@@ -965,15 +1114,9 @@ public:
 #  else
 #    error "Undefined byte order"
 #  endif
-#endif
     };
-#if !defined(Q_BYTE_ORDER)
-#  if defined(QT_BUILD_QMAKE)
-    /* needed to bootstrap qmake */
-    static const int ByteOrder;
-#  else
-#    error "Qt not configured correctly, please run configure"
-#  endif
+#else
+#  error "Qt not configured correctly, please run configure"
 #endif
 #ifdef Q_WS_WIN
     enum WinVersion {
@@ -996,7 +1139,7 @@ public:
     };
     static const WinVersion WindowsVersion;
 #endif
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
     enum MacVersion {
         MV_Unknown = 0x0000,
 
@@ -1007,13 +1150,15 @@ public:
         MV_10_2 = 0x0004,
         MV_10_3 = 0x0005,
         MV_10_4 = 0x0006,
+        MV_10_5 = 0x0007,
 
         /* codenames */
         MV_CHEETAH = MV_10_0,
         MV_PUMA = MV_10_1,
         MV_JAGUAR = MV_10_2,
         MV_PANTHER = MV_10_3,
-        MV_TIGER = MV_10_4
+        MV_TIGER = MV_10_4,
+        MV_LEOPARD = MV_10_5
     };
     static const MacVersion MacintoshVersion;
 #endif
@@ -1068,7 +1213,7 @@ inline QT3_SUPPORT int qWinVersion() { return QSysInfo::WindowsVersion; }
    Avoid "unused parameter" warnings
 */
 
-#if defined(Q_CC_INTEL)
+#if defined(Q_CC_INTEL) && !defined(Q_OS_WIN)
 template <typename T>
 inline void qUnused(T &x) { (void)x; }
 #  define Q_UNUSED(x) qUnused(x);
@@ -1119,18 +1264,33 @@ Q_CORE_EXPORT QT3_SUPPORT void qSystemWarning(const char *msg, int code = -1);
 Q_CORE_EXPORT void qErrnoWarning(int code, const char *msg, ...);
 Q_CORE_EXPORT void qErrnoWarning(const char *msg, ...);
 
+#if (defined(QT_NO_DEBUG_OUTPUT) || defined(QT_NO_TEXTSTREAM)) && !defined(QT_NO_DEBUG_STREAM)
+#define QT_NO_DEBUG_STREAM
+#endif
+
+/*
+  Forward declarations only.
+
+  In order to use the qDebug() stream, you must #include<QDebug>
+*/
 class QDebug;
 class QNoDebug;
+#ifndef QT_NO_DEBUG_STREAM
+Q_CORE_EXPORT_INLINE QDebug qDebug();
+Q_CORE_EXPORT_INLINE QDebug qWarning();
+Q_CORE_EXPORT_INLINE QDebug qCritical();
+#else
+inline QNoDebug qDebug();
+#endif
 
+#define QT_NO_QDEBUG_MACRO if(1); else qDebug
 #ifdef QT_NO_DEBUG_OUTPUT
-#  define qDebug if(1); else qDebug
+#  define qDebug QT_NO_QDEBUG_MACRO
 #endif
 #ifdef QT_NO_WARNING_OUTPUT
 #  define qWarning if(1); else qWarning
 #endif
-#if (defined(QT_NO_DEBUG_OUTPUT) || defined(QT_NO_TEXTSTREAM)) && !defined(QT_NO_DEBUG_STREAM)
-#define QT_NO_DEBUG_STREAM
-#endif
+
 
 inline void qt_noop() {}
 
@@ -1162,6 +1322,33 @@ Q_CORE_EXPORT void qt_check_pointer(const char *, int);
 #  define Q_CHECK_PTR(p)
 #endif
 
+#if (defined(Q_CC_GNU) && !defined(Q_OS_SOLARIS)) || defined(Q_CC_HPACC)
+#  define Q_FUNC_INFO __PRETTY_FUNCTION__
+#elif defined(_MSC_VER)
+    /* MSVC 2002 doesn't have __FUNCSIG__ nor can it handle QT_STRINGIFY. */
+#  if _MSC_VER <= 1300
+#      define Q_FUNC_INFO __FILE__ "(line number unavailable)"
+#  else
+#      define Q_FUNC_INFO __FUNCSIG__
+#  endif
+#else
+#   if defined(Q_OS_SOLARIS) || defined(Q_CC_XLC)
+#      define Q_FUNC_INFO __FILE__ "(line number unavailable)"
+#   else
+        /* These two macros makes it possible to turn the builtin line expander into a
+         * string literal. */
+#       define QT_STRINGIFY2(x) #x
+#       define QT_STRINGIFY(x) QT_STRINGIFY2(x)
+#       define Q_FUNC_INFO __FILE__ ":" QT_STRINGIFY(__LINE__)
+#   endif
+    /* The MIPSpro compiler postpones macro expansion, and therefore macros must be in scope
+     * when being used. */
+#   if !defined(Q_CC_MIPS)
+#       undef QT_STRINGIFY2
+#       undef QT_STRINGIFY
+#   endif
+#endif
+
 enum QtMsgType { QtDebugMsg, QtWarningMsg, QtCriticalMsg, QtFatalMsg, QtSystemMsg = QtCriticalMsg };
 
 Q_CORE_EXPORT void qt_message_output(QtMsgType, const char *buf);
@@ -1203,45 +1390,69 @@ public:
 
 #else
 
+// forward declaration, since qatomic.h needs qglobal.h
+template <typename T> struct QBasicAtomicPointer;
+
+// POD for Q_GLOBAL_STATIC
 template <typename T>
 class QGlobalStatic
 {
 public:
     T *pointer;
     bool destroyed;
+};
 
-    inline QGlobalStatic()
-        : pointer(0), destroyed(false)
+// Created as a function-local static to delete a QGlobalStatic<T>
+template <typename T>
+class QGlobalStaticDeleter
+{
+public:
+    QGlobalStatic<T> &globalStatic;
+    QGlobalStaticDeleter(QGlobalStatic<T> &_globalStatic)
+        : globalStatic(_globalStatic)
     { }
 
-    inline ~QGlobalStatic()
+    inline ~QGlobalStaticDeleter()
     {
-        delete pointer;
-        pointer = 0;
-        destroyed = true;
+        delete globalStatic.pointer;
+        globalStatic.pointer = 0;
+        globalStatic.destroyed = true;
     }
 };
 
+#if (defined Q_OS_HPUX && defined Q_CC_HPACC && !defined __ia64)
+// aCC 3.x bug
+#  define Q_GLOBAL_STATIC_INIT(TYPE, NAME)                              \
+    static QGlobalStatic<TYPE > this_##NAME
+#else
+#  define Q_GLOBAL_STATIC_INIT(TYPE, NAME)                              \
+    static QGlobalStatic<TYPE > this_##NAME = { 0, false }
+#endif
+
 #define Q_GLOBAL_STATIC(TYPE, NAME)                                     \
+    Q_GLOBAL_STATIC_INIT(TYPE, NAME);                                   \
     static TYPE *NAME()                                                 \
     {                                                                   \
-        static QGlobalStatic<TYPE > this_##NAME;                        \
         if (!this_##NAME.pointer && !this_##NAME.destroyed) {           \
             TYPE *x = new TYPE;                                         \
             if (!q_atomic_test_and_set_ptr(&this_##NAME.pointer, 0, x)) \
                 delete x;                                               \
+            else                                                        \
+                static QGlobalStaticDeleter<TYPE > cleanup(this_##NAME); \
         }                                                               \
-        return this_##NAME.pointer;                                   \
+        return this_##NAME.pointer;                                     \
     }
 
 #define Q_GLOBAL_STATIC_WITH_ARGS(TYPE, NAME, ARGS)                     \
+    Q_GLOBAL_STATIC_INIT(TYPE, NAME);                                   \
     static TYPE *NAME()                                                 \
     {                                                                   \
-        static QGlobalStatic<TYPE > this_##NAME;                        \
         if (!this_##NAME.pointer && !this_##NAME.destroyed) {           \
             TYPE *x = new TYPE ARGS;                                    \
             if (!q_atomic_test_and_set_ptr(&this_##NAME.pointer, 0, x)) \
                 delete x;                                               \
+            else                                                        \
+                static QGlobalStaticDeleter<TYPE > cleanup(this_##NAME); \
         }                                                               \
         return this_##NAME.pointer;                                     \
     }
@@ -1428,8 +1639,33 @@ public: \
    types must declare a 'bool isDetached(void) const;' member for this
    to work.
 */
-#define Q_DECLARE_SHARED(TYPE) \
-template <> inline bool qIsDetached<TYPE>(TYPE &t) { return t.isDetached(); }
+#if defined Q_CC_MSVC && _MSC_VER < 1300
+template <typename T>
+inline void qSwap_helper(T &value1, T &value2, T*)
+{
+    T t = value1;
+    value1 = value2;
+    value2 = t;
+}
+#define Q_DECLARE_SHARED(TYPE)                                          \
+template <> inline bool qIsDetached<TYPE>(TYPE &t) { return t.isDetached(); } \
+template <> inline void qSwap_helper<TYPE>(TYPE &value1, TYPE &value2, TYPE*) \
+{ \
+    const TYPE::DataPtr t = value1.data_ptr(); \
+    value1.data_ptr() = value2.data_ptr(); \
+    value2.data_ptr() = t; \
+}
+#else
+#define Q_DECLARE_SHARED(TYPE)                                          \
+template <> inline bool qIsDetached<TYPE>(TYPE &t) { return t.isDetached(); } \
+template <typename T> inline void qSwap(T &, T &); \
+template <> inline void qSwap<TYPE>(TYPE &value1, TYPE &value2) \
+{ \
+    const TYPE::DataPtr t = value1.data_ptr(); \
+    value1.data_ptr() = value2.data_ptr(); \
+    value2.data_ptr() = t; \
+}
+#endif
 
 /*
    QTypeInfo primitive specializations
@@ -1523,15 +1759,14 @@ public:
     inline QFlags(QFlag f) : i(f) {}
 
     inline QFlags &operator=(const QFlags &f) { i = f.i; return *this; }
-    inline QFlags &operator&=(int mask) {  i &= mask; return *this; }
-    inline QFlags &operator&=(uint mask) {  i &= mask; return *this; }
-    inline QFlags &operator|=(QFlags f) {  i |= f.i; return *this; }
-    inline QFlags &operator|=(Enum f) {  i |= f; return *this; }
-    inline QFlags &operator^=(QFlags f) {  i ^= f.i; return *this; }
-    inline QFlags &operator^=(Enum f) {  i ^= f; return *this; }
+    inline QFlags &operator&=(int mask) { i &= mask; return *this; }
+    inline QFlags &operator&=(uint mask) { i &= mask; return *this; }
+    inline QFlags &operator|=(QFlags f) { i |= f.i; return *this; }
+    inline QFlags &operator|=(Enum f) { i |= f; return *this; }
+    inline QFlags &operator^=(QFlags f) { i ^= f.i; return *this; }
+    inline QFlags &operator^=(Enum f) { i ^= f; return *this; }
 
-
-    inline operator int() const { return i;}
+    inline operator int() const { return i; }
 
     inline QFlags operator|(QFlags f) const { QFlags g; g.i = i | f.i; return g; }
     inline QFlags operator|(Enum f) const { QFlags g; g.i = i | f; return g; }
@@ -1543,6 +1778,13 @@ public:
     inline QFlags operator~() const { QFlags g; g.i = ~i; return g; }
 
     inline bool operator!() const { return !i; }
+
+    inline bool testFlag(Enum f) const { return i & f; }
+
+private:
+#if QT_VERSION >= 0x050000 && !defined(Q_NO_DECLARED_NOT_DEFINED)
+    explicit QFlags(bool);
+#endif
 };
 
 #define Q_DECLARE_FLAGS(Flags, Enum)\
@@ -1561,7 +1803,7 @@ typedef uint Flags;
 
 #endif /* Q_NO_TYPESAFE_FLAGS */
 
-#if defined(Q_CC_GNU) && !defined(Q_CC_INTEL)
+#if defined(Q_CC_GNU) && !defined(Q_CC_INTEL) && !defined(Q_OS_OPENBSD)
 /* make use of typeof-extension */
 template <typename T>
 class QForeachContainer {
@@ -1601,13 +1843,28 @@ template <typename T>
 inline const QForeachContainer<T> *qForeachContainer(const QForeachContainerBase *base, const T *)
 { return static_cast<const QForeachContainer<T> *>(base); }
 
-#define Q_FOREACH(variable, container) \
+#if (defined(Q_CC_MSVC) && !defined(Q_CC_MSVC_NET) && !defined(Q_CC_INTEL)) || defined(Q_CC_MIPS)
+/*
+   Proper for-scoping in VC++6 and MIPSpro CC
+*/
+#  define Q_FOREACH(variable,container)                                                             \
+    if(0){}else                                                                                     \
+    for (const QForeachContainerBase &_container_ = qForeachContainerNew(container);                \
+         qForeachContainer(&_container_, true ? 0 : qForeachPointer(container))->condition();       \
+         ++qForeachContainer(&_container_, true ? 0 : qForeachPointer(container))->i)               \
+        for (variable = *qForeachContainer(&_container_, true ? 0 : qForeachPointer(container))->i; \
+             qForeachContainer(&_container_, true ? 0 : qForeachPointer(container))->brk;           \
+             --qForeachContainer(&_container_, true ? 0 : qForeachPointer(container))->brk)
+
+#else
+#  define Q_FOREACH(variable, container) \
     for (const QForeachContainerBase &_container_ = qForeachContainerNew(container); \
          qForeachContainer(&_container_, true ? 0 : qForeachPointer(container))->condition();       \
          ++qForeachContainer(&_container_, true ? 0 : qForeachPointer(container))->i)               \
         for (variable = *qForeachContainer(&_container_, true ? 0 : qForeachPointer(container))->i; \
              qForeachContainer(&_container_, true ? 0 : qForeachPointer(container))->brk;           \
              --qForeachContainer(&_container_, true ? 0 : qForeachPointer(container))->brk)
+#endif // MSVC6 || MIPSpro
 
 #endif
 
@@ -1666,6 +1923,11 @@ Q_CORE_EXPORT QByteArray qgetenv(const char *varName);
 inline int qIntCast(double f) { return int(f); }
 inline int qIntCast(float f) { return int(f); }
 
+/*
+  Reentrant versions of basic rand() functions for random number generation
+*/
+Q_CORE_EXPORT void qsrand(uint seed);
+Q_CORE_EXPORT int qrand();
 
 /*
    Compat functions that were generated by configure
@@ -1704,11 +1966,14 @@ QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathSysconf();
 #define QT_MODULE_QT3SUPPORT            0x080
 #define QT_MODULE_SVG                   0x100
 #define QT_MODULE_ACTIVEQT              0x200
+#define QT_MODULE_GRAPHICSVIEW          0x400
+#define QT_MODULE_SCRIPT                0x800
 
 /* Qt editions */
 #define QT_EDITION_CONSOLE      (QT_MODULE_CORE \
                                  | QT_MODULE_NETWORK \
                                  | QT_MODULE_SQL \
+                                 | QT_MODULE_SCRIPT \
                                  | QT_MODULE_XML)
 #define QT_EDITION_DESKTOPLIGHT (QT_MODULE_CORE \
                                  | QT_MODULE_GUI \
@@ -1719,9 +1984,11 @@ QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathSysconf();
                                  | QT_MODULE_OPENGL \
                                  | QT_MODULE_SQL \
                                  | QT_MODULE_XML \
+                                 | QT_MODULE_SCRIPT \
                                  | QT_MODULE_QT3SUPPORTLIGHT \
                                  | QT_MODULE_QT3SUPPORT \
-                                 | QT_MODULE_SVG)
+                                 | QT_MODULE_SVG \
+                                 | QT_MODULE_GRAPHICSVIEW)
 #define QT_EDITION_DESKTOP      (QT_EDITION_OPENSOURCE \
                                  | QT_MODULE_ACTIVEQT)
 #define QT_EDITION_UNIVERSAL    QT_EDITION_DESKTOP
@@ -1759,6 +2026,9 @@ QT_LICENSED_MODULE(Sql)
 #if (QT_EDITION & QT_MODULE_XML)
 QT_LICENSED_MODULE(Xml)
 #endif
+#if (QT_EDITION & QT_MODULE_SCRIPT)
+QT_LICENSED_MODULE(Script)
+#endif
 #if (QT_EDITION & QT_MODULE_QT3SUPPORTLIGHT)
 QT_LICENSED_MODULE(Qt3SupportLight)
 #endif
@@ -1775,6 +2045,8 @@ QT_LICENSED_MODULE(ActiveQt)
 #define QT_MODULE(x) \
     typedef QtValidLicenseFor##x##Module Qt##x##Module;
 
+QT_END_HEADER
+
 #endif /* __cplusplus */
 
 #endif /* QGLOBAL_H */
