@@ -23,6 +23,12 @@
 # define QT_BUILTIN_GIF_READER 1
 #endif
 
+#if defined(QT_NO_CLOCK_MONOTONIC) && defined(QT_CLOCK_MONOTONIC)
+# undef QT_NO_CLOCK_MONOTONIC
+#elif !defined(QT_NO_CLOCK_MONOTONIC) && !defined(QT_CLOCK_MONOTONIC)
+# define QT_NO_CLOCK_MONOTONIC
+#endif
+
 #if defined(QT_NO_EXCEPTIONS) && defined(QT_EXCEPTIONS)
 # undef QT_NO_EXCEPTIONS
 #elif !defined(QT_NO_EXCEPTIONS) && !defined(QT_EXCEPTIONS)
@@ -41,12 +47,24 @@
 # define QT_NO_IMAGEFORMAT_MNG
 #endif
 
+#if defined(QT_NO_IMAGEFORMAT_TIFF) && defined(QT_IMAGEFORMAT_TIFF)
+# undef QT_NO_IMAGEFORMAT_TIFF
+#elif !defined(QT_NO_IMAGEFORMAT_TIFF) && !defined(QT_IMAGEFORMAT_TIFF)
+# define QT_NO_IMAGEFORMAT_TIFF
+#endif
+
 #if defined(QT_NO_INOTIFY) && defined(QT_INOTIFY)
 # undef QT_NO_INOTIFY
 #elif !defined(QT_NO_INOTIFY) && !defined(QT_INOTIFY)
 # define QT_NO_INOTIFY
 #endif
 
+#if defined(QT_NO_MREMAP) && defined(QT_MREMAP)
+# undef QT_NO_MREMAP
+#elif !defined(QT_NO_MREMAP) && !defined(QT_MREMAP)
+# define QT_NO_MREMAP
+#endif
+
 #if defined(QT_NO_NAS) && defined(QT_NAS)
 # undef QT_NO_NAS
 #elif !defined(QT_NO_NAS) && !defined(QT_NAS)
@@ -65,3 +83,9 @@
 # define QT_NO_ZLIB
 #endif
 
+#if defined(QT_USE_MATH_H_FLOATS) && defined(QT_NO_USE_MATH_H_FLOATS)
+# undef QT_USE_MATH_H_FLOATS
+#elif !defined(QT_USE_MATH_H_FLOATS) && !defined(QT_NO_USE_MATH_H_FLOATS)
+# define QT_USE_MATH_H_FLOATS
+#endif
+
