@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
@@ -28,6 +28,8 @@
 #include <QtCore/qpair.h>
 #include <QtCore/qstring.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Core)
 
 class QByteArray;
@@ -106,6 +108,8 @@ public:
     void setPath(const QString &path);
     QString path() const;
 
+    bool hasQuery() const;
+
     void setEncodedQuery(const QByteArray &query);
     QByteArray encodedQuery() const;
 
@@ -124,6 +128,7 @@ public:
 
     void setFragment(const QString &fragment);
     QString fragment() const;
+    bool hasFragment() const;
 
     QUrl resolved(const QUrl &relative) const;
 
@@ -153,6 +158,10 @@ public:
                                         const QByteArray &include = QByteArray());
     static QString fromPunycode(const QByteArray &);
     static QByteArray toPunycode(const QString &);
+    static QString fromAce(const QByteArray &);
+    static QByteArray toAce(const QString &);
+    static QStringList idnWhitelist();
+    static void setIdnWhitelist(const QStringList &);
 
 #if defined QT3_SUPPORT
     inline QT3_SUPPORT QString protocol() const { return scheme(); }
@@ -199,6 +208,8 @@ public:
     }
 #endif
 
+    QString errorString() const;
+
 protected:
 #if defined (QT3_SUPPORT)
     inline QT3_SUPPORT void reset() { clear(); }
@@ -206,6 +217,9 @@ protected:
 
 private:
     QUrlPrivate *d;
+public:
+    typedef QUrlPrivate * DataPtr;
+    inline DataPtr &data_ptr() { return d; }
 };
 
 Q_DECLARE_TYPEINFO(QUrl, Q_MOVABLE_TYPE);
@@ -221,4 +235,6 @@ Q_CORE_EXPORT QDataStream &operator>>(QDataStream &, QUrl &);
 Q_CORE_EXPORT QDebug operator<<(QDebug, const QUrl &);
 #endif
 
+QT_END_HEADER
+
 #endif // QURL_H
